@@ -1,6 +1,5 @@
-# coding: utf-8
-# vim: set ts=4 sw=4 expandtab sts=4:
-# Copyright (c) 2011-2014 Christian Geier & contributors
+# vim: set ts=4 sw=4 expandtab sts=4 fileencoding=utf-8:
+# Copyright (c) 2011-2014 Christian Geier et al.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,15 +20,20 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+from .compat import to_unicode
+
 from datetime import date, datetime, timedelta
 from datetime import time as dtime
 import random
 import string
+import sys
 import time
 
 import icalendar
 import pytz
 
+from khal.log import logger
+
 
 def timefstr(date_list, timeformat):
     """
@@ -183,7 +187,9 @@ def construct_event(date_list, timeformat, dateformat, longdateformat,
                 dtstart = datetimefstr(date_list, dateformat, longdateformat)
                 all_day = True
             except ValueError:
-                raise
+                logger.fatal("Cannot parse: '{}'\nPlease have a look at the "
+                             "the documentation.".format(' '.join(date_list)))
+                sys.exit()
 
     # now looking for the end
     if all_day:
@@ -236,7 +242,7 @@ def construct_event(date_list, timeformat, dateformat, longdateformat,
             dtend = defaulttz.localize(dtend)
 
     event = icalendar.Event()
-    text = ' '.join(date_list).decode(encoding)
+    text = to_unicode(' '.join(date_list), encoding)
     summary = text.split(' :: ', 1)[0]
 
     try:
