@@ -1,6 +1,5 @@
-# coding: utf-8
-# vim: set ts=4 sw=4 expandtab sts=4:
-# Copyright (c) 2011-2014 Christian Geier & contributors
+# vim: set ts=4 sw=4 expandtab sts=4 fileencoding=utf-8:
+# Copyright (c) 2011-2014 Christian Geier et al.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,7 +31,27 @@ from khal import __version__, __productname__
 from .terminal import bstring, colored, get_terminal_size, merge_columns
 
 
-def get_agenda(collection, dateformat, longdateformat, dates=[], width=45):
+def construct_daynames(daylist, longdateformat):
+    """returns a list of tuples of datetime objects and datenames
+
+    :param daylist: list of dates
+    :type daylist: list(datetime.date)
+    :param longdateformat: format in which to print dates
+    :param str
+    :returns: list of names and dates
+    :rtype: list((str, datetime.date))
+    """
+    for date in daylist:
+        if date == datetime.date.today():
+            yield (date, u'Today:')
+        elif date == datetime.date.today() + datetime.timedelta(days=1):
+            yield (date, u'Tomorrow:')
+        else:
+            yield (date, date.strftime(longdateformat))
+
+
+def get_agenda(collection, dateformat, longdateformat, dates=[],
+               days=None, events=None, width=45):
     """returns a list of events scheduled for all days in daylist
 
     included are header "rows"
@@ -45,40 +64,51 @@ def get_agenda(collection, dateformat, longdateformat, dates=[], width=45):
     :rtype: list(str)
 
     """
+    assert not (days is not None and events is not None)
     event_column = list()
 
+    if days is None:
+        days = 2
+
     if dates == []:
-        today = datetime.date.today()
-        tomorrow = today + datetime.timedelta(days=1)
-        daylist = [(today, 'Today:'), (tomorrow, 'Tomorrow:')]
+        dates = [datetime.date.today()]
     else:
         try:
-            daylist = [aux.datefstr(date, dateformat, longdateformat)
-                       for date in dates]
+            dates = [aux.datefstr(date, dateformat, longdateformat)
+                     for date in dates]
         except aux.InvalidDate as error:
             logging.fatal(error)
             sys.exit(1)
-        daynames = [date.strftime(longdateformat) for date in daylist]
 
-        daylist = zip(daylist, daynames)
+    if days is not None:
+        daylist = [date + datetime.timedelta(days=one) for one in range(days) for date in dates]
+        daylist.sort()
+
+    daylist = construct_daynames(daylist, longdateformat)
 
     for day, dayname in daylist:
         # TODO unify allday and datetime events
         start = datetime.datetime.combine(day, datetime.time.min)
         end = datetime.datetime.combine(day, datetime.time.max)
 
-        event_column.append(bstring(dayname))
-
         all_day_events = collection.get_allday_by_time_range(day)
         events = collection.get_datetime_by_time_range(start, end)
+        if len(events) == 0 and len(all_day_events) == 0:
+            continue
+
+        event_column.append(bstring(dayname))
         for event in all_day_events:
             desc = textwrap.wrap(event.compact(day), width)
             event_column.extend([colored(d, event.color) for d in desc])
 
         events.sort(key=lambda e: e.start)
+
         for event in events:
             desc = textwrap.wrap(event.compact(day), width)
             event_column.extend([colored(d, event.color) for d in desc])
+
+    if event_column == []:
+        event_column = [bstring('No Events')]
     return event_column
 
 
@@ -112,17 +142,17 @@ class NewFromString(object):
 
     def __init__(self, collection, conf, date_list):
         event = aux.construct_event(date_list,
-                                    conf.locale.timeformat,
-                                    conf.locale.dateformat,
-                                    conf.locale.longdateformat,
-                                    conf.locale.datetimeformat,
-                                    conf.locale.longdatetimeformat,
-                                    conf.locale.local_timezone,
-                                    encoding=conf.locale.encoding)
+                                    conf['locale']['timeformat'],
+                                    conf['locale']['dateformat'],
+                                    conf['locale']['longdateformat'],
+                                    conf['locale']['datetimeformat'],
+                                    conf['locale']['longdatetimeformat'],
+                                    conf['locale']['local_timezone'],
+                                    encoding=conf['locale']['encoding'])
         event = collection.new_event(event,
                                      collection.default_calendar_name,
-                                     conf.locale.local_timezone,
-                                     conf.locale.default_timezone,
+                                     conf['locale']['local_timezone'],
+                                     conf['locale']['default_timezone'],
                                      )
 
         collection.new(event)
