@@ -1,6 +1,5 @@
-# coding: utf-8
-# vim: set ts=4 sw=4 expandtab sts=4:
-# Copyright (c) 2011-2014 Christian Geier & contributors
+# vim: set ts=4 sw=4 expandtab sts=4 fileencoding=utf-8:
+# Copyright (c) 2011-2014 Christian Geier et al.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -76,6 +75,8 @@ import xdg.BaseDirectory
 from .event import Event
 from . import datetimehelper
 from .. import log
+from ..exceptions import Error
+from exceptions import UnsupportedRruleExceptionError
 
 logger = log.logger
 
@@ -133,7 +134,7 @@ class SQLiteDb(object):
                 logger.debug('success')
             except OSError as error:
                 logger.fatal('failed to create {0}: {1}'.format(dbdir, error))
-                raise CouldNotCreateDbDir
+                raise CouldNotCreateDbDir()
 
     def _check_table_version(self):
         """tests for curent db Version
@@ -269,28 +270,35 @@ class SQLiteDb(object):
         if href is None:
             raise ValueError('href may not be one')
         self._check_account(account)
+        events = []
         if not isinstance(vevent, icalendar.cal.Event):
             ical = icalendar.Event.from_ical(vevent)
-            vevent = None
             for component in ical.walk():
                 if component.name == 'VEVENT':
-                    vevent = component
-                    break
+                    events.append(component)
 
-        if vevent is None:
+        if len(events) == 0:
             if ignore_invalid_items:
                 return
             else:
                 raise UpdateFailed(u'Could not find event in {}'.format(ical))
 
+        elif len(events) > 1:
+            if len(set([event['UID'] for event in events])):
+                raise UnsupportedRruleExceptionError()
+            else:
+                raise Error('more than one event in .ics file')
+
+        vevent = events[0]
         vevent = datetimehelper.sanitize(vevent)
 
         all_day_event = False
         if href == '' or href is None:
             href = get_random_href()
-        if 'VALUE' in vevent['DTSTART'].params:
-            if vevent['DTSTART'].params['VALUE'] == 'DATE':
-                all_day_event = True
+
+        # testing on datetime.date won't work as datetime is a child of date
+        if not isinstance(vevent['DTSTART'].dt, datetime.datetime):
+            all_day_event = True
 
         dtstartend = datetimehelper.expand(vevent,
                                            self.default_tz,
@@ -448,6 +456,8 @@ class SQLiteDb(object):
     def get_allday_range(self, start, end=None, account=None, color='',
                          readonly=False, unicode_symbols=True,
                          show_deleted=True):
+        # TODO type check on start and end
+        # should be datetime.date not datetime.datetime
         self._check_account(account)
         if account is None:
             raise Exception('need to specify an account')
